Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1055)

Unified Diff: chrome/browser/download/download_request_limiter_unittest.cc

Issue 2081103002: Rename PermissionBubbleManager to PermissionRequestManager (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Review comments Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/download/download_request_limiter_unittest.cc
diff --git a/chrome/browser/download/download_request_limiter_unittest.cc b/chrome/browser/download/download_request_limiter_unittest.cc
index 3583e49dbb7f1fbb0bfc32fb3d6d4b4180f55a67..4dab572a0b607583be976a7a5ad4ef3f50a4efcb 100644
--- a/chrome/browser/download/download_request_limiter_unittest.cc
+++ b/chrome/browser/download/download_request_limiter_unittest.cc
@@ -27,8 +27,8 @@
#include "chrome/browser/infobars/infobar_service.h"
#else
#include "chrome/browser/download/download_permission_request.h"
+#include "chrome/browser/permissions/permission_request_manager.h"
#include "chrome/browser/ui/website_settings/mock_permission_bubble_factory.h"
-#include "chrome/browser/ui/website_settings/permission_bubble_manager.h"
#endif
using content::WebContents;
@@ -98,10 +98,10 @@ class TestingDelegate {
class TestingDelegate {
public:
void SetUp(WebContents* web_contents) {
- PermissionBubbleManager::CreateForWebContents(web_contents);
+ PermissionRequestManager::CreateForWebContents(web_contents);
mock_permission_bubble_factory_.reset(new MockPermissionBubbleFactory(
- PermissionBubbleManager::FromWebContents(web_contents)));
- PermissionBubbleManager::FromWebContents(web_contents)
+ PermissionRequestManager::FromWebContents(web_contents)));
+ PermissionRequestManager::FromWebContents(web_contents)
->DisplayPendingRequests();
}
@@ -116,19 +116,19 @@ class TestingDelegate {
int AllowCount() { return mock_permission_bubble_factory_->show_count(); }
void UpdateExpectations(TestingAction action) {
// Set expectations for PermissionBubbleManager.
if (action == ACCEPT) {
mock_permission_bubble_factory_->set_response_type(
- PermissionBubbleManager::ACCEPT_ALL);
+ PermissionRequestManager::ACCEPT_ALL);
} else if (action == CANCEL) {
mock_permission_bubble_factory_->set_response_type(
- PermissionBubbleManager::DENY_ALL);
+ PermissionRequestManager::DENY_ALL);
} else if (action == WAIT) {
mock_permission_bubble_factory_->set_response_type(
- PermissionBubbleManager::NONE);
+ PermissionRequestManager::NONE);
} else {
mock_permission_bubble_factory_->set_response_type(
- PermissionBubbleManager::DISMISS);
+ PermissionRequestManager::DISMISS);
}
}
@@ -116,19 +116,19 @@ class TestingDelegate {
int AllowCount() { return mock_permission_bubble_factory_->show_count(); }
void UpdateExpectations(TestingAction action) {
- // Set expectations for PermissionBubbleManager.
+ // Set expectations for PermissionRequestManager.
if (action == ACCEPT) {
mock_permission_bubble_factory_->set_response_type(

Powered by Google App Engine
This is Rietveld 408576698